addresses.Address (Address) — amici1

# `addresses.Address` (Address)

Address(id, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, data_source, address_type, partner, remark, primary)

Master tables : addresses.Addresses (Addresses)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Country (country) : See `<django.db.models.fields.related.ForeignKey: country>`.

- Locality (city) : The locality, i.e. usually a village, city or town.

- Zip code (zip_code) : See `<django.db.models.fields.CharField: zip_code>`.

- County (region) : See `<django.db.models.fields.related.ForeignKey: region>`.

- Address line before street (addr1) : Address line before street

- Street prefix (street_prefix) : Text to print before name of street, but to ignore for sorting.

- Street (street) : Name of street, without house number.

- No. (street_no) : House number.

- Box (street_box) : Text to print after street number on the same line.

- Address line after street (addr2) : Address line to print below street line.

- Data source (data_source) : Pointer to DataSources.

- Address type (address_type) : The type of this address record. A pointer to AddressTypes. The default value is AddressTypes.official.

- Partner (partner) : See `<django.db.models.fields.related.ForeignKey: partner>`.

- Remark (remark) : See `<lino.core.fields.CharField: remark>`.

- Primary (primary) : Whether this address is the primary address of its owner. Setting this field will automatically uncheck any previousl primary addresses and update the owner’s address fields.

- Address (address_column) : See `lino_xl.lib.addresses.models.Address.address_column`.

- Municipality (municipality) : The municipality, i.e. either the city or a parent of it.

- Name (name_column) : See `lino_xl.lib.addresses.models.Address.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.addresses.models.Address.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.addresses.models.Address.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
country | Country |
city | Locality | The locality, i.e. usually a village, city or town.
zip_code | Zip code |
region | County |
addr1 | Address line before street | Address line before street
street_prefix | Street prefix | Text to print before name of street, but to ignore for sorting.
street | Street | Name of street, without house number.
street_no | No. | House number.
street_box | Box | Text to print after street number on the same line.
addr2 | Address line after street | Address line to print below street line.
data_source | Data source | Pointer to DataSources.
address_type | Address type | The type of this address record. A pointer to AddressTypes. The default value is AddressTypes.official.
partner | Partner |
remark | Remark |
primary | Primary | Whether this address is the primary address of its owner. Setting this field will automatically uncheck any previousl primary addresses and update the owner’s address fields.
address_column | Address |
municipality | Municipality | The municipality, i.e. either the city or a parent of it.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |